@@ -3,6 +3,7 @@ register and verify
 """
 
 from dataclasses import dataclass, field
+from traceback import format_exc
 from typing import Optional
 
 from sanic import Blueprint
@@ -66,10 +67,9 @@ async def register_post(
             return json({"error": result}, 400)
         return json(None, 200)
     # pylint: disable=broad-except
-    except Exception as err:
-        error = getattr(err, "message", repr(err))
-        logger.error(error)
-        return json({"error": error}, 400)
+    except Exception:
+        logger.error(format_exc())
+        return {"error": "An eror occured. Please check gateway logs."}, 400
 
 
 @dataclass
@@ -120,7 +120,6 @@ async def verify_post(
             return json({"error": result}, 400)
         return json(None, 200)
     # pylint: disable=broad-except
-    except Exception as err:
-        error = getattr(err, "message", repr(err))
-        logger.error(error)
-        return json({"error": error}, 400)
+    except Exception:
+        logger.error(format_exc())
+        return {"error": "An eror occured. Please check gateway logs."}, 400
