@@ -12,6 +12,12 @@ from sanic import Sanic
 from sanic.log import logger
 
 
+class JSONRPCResponseException(Exception):
+    """
+    JSONRPCResponseException
+    """
+
+
 @dataclass
 class EmptyApp:
     """
@@ -55,9 +61,11 @@ def jsonrpc(data: dict, host: str = "localhost", port: int = 7583):
                     logger.debug("JSON RPC response: %s", recv_content)
                     recv_buffer = []
                     if res.get("id") == request_id:
+                        if res.get("error"):
+                            raise JSONRPCResponseException(
+                                res.get("error").get("message")
+                            )
                         return res
         except Exception as err:  # pylint: disable=broad-except
             error = getattr(err, "message", repr(err))
-            raise RuntimeError(
-                f"Unable to connect to signal-cli JSON RPC: {error}"
-            ) from err
+            raise RuntimeError(f"signal-cli JSON RPC request failed: {error}") from err
